==> zio-aws-ec2_2.12-5.19.7.2-sources.jar: zio/aws/ec2/model/AllowedPrincipal.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class AllowedPrincipal(
    principalType: Optional[zio.aws.ec2.model.PrincipalType] = Optional.Absent,
    principal: Optional[String] = Optional.Absent,
    servicePermissionId: Optional[String] = Optional.Absent,
    tags: Optional[Iterable[zio.aws.ec2.model.Tag]] = Optional.Absent,
    serviceId: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.AllowedPrincipal = {
    import AllowedPrincipal.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.AllowedPrincipal
      .builder()
      .optionallyWith(principalType.map(value => value.unwrap))(_.principalType)
      .optionallyWith(principal.map(value => value: java.lang.String))(
        _.principal
      )
      .optionallyWith(
        servicePermissionId.map(value => value: java.lang.String)
      )(_.servicePermissionId)
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .optionallyWith(serviceId.map(value => value: java.lang.String))(
        _.serviceId
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.AllowedPrincipal.ReadOnly =
    zio.aws.ec2.model.AllowedPrincipal.wrap(buildAwsValue())
}
object AllowedPrincipal {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.AllowedPrincipal
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.AllowedPrincipal =
      zio.aws.ec2.model.AllowedPrincipal(
        principalType.map(value => value),
        principal.map(value => value),
        servicePermissionId.map(value => value),
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        serviceId.map(value => value)
      )
    def principalType: Optional[zio.aws.ec2.model.PrincipalType]
    def principal: Optional[String]
    def servicePermissionId: Optional[String]
    def tags: Optional[List[zio.aws.ec2.model.Tag.ReadOnly]]
    def serviceId: Optional[String]
    def getPrincipalType: ZIO[Any, AwsError, zio.aws.ec2.model.PrincipalType] =
      AwsError.unwrapOptionField("principalType", principalType)
    def getPrincipal: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("principal", principal)
    def getServicePermissionId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("servicePermissionId", servicePermissionId)
    def getTags: ZIO[Any, AwsError, List[zio.aws.ec2.model.Tag.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getServiceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("serviceId", serviceId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.AllowedPrincipal
  ) extends zio.aws.ec2.model.AllowedPrincipal.ReadOnly {
    override val principalType: Optional[zio.aws.ec2.model.PrincipalType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.principalType())
        .map(value => zio.aws.ec2.model.PrincipalType.wrap(value))
    override val principal: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.principal())
      .map(value => value: String)
    override val servicePermissionId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.servicePermissionId())
      .map(value => value: String)
    override val tags: Optional[List[zio.aws.ec2.model.Tag.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ec2.model.Tag.wrap(item)
          }.toList
        )
    override val serviceId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.serviceId())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.AllowedPrincipal
  ): zio.aws.ec2.model.AllowedPrincipal.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.102.7-sources.jar: zio/aws/ec2/model/AllowedPrincipal.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class AllowedPrincipal(
    principalType: Option[zio.aws.ec2.model.PrincipalType] = None,
    principal: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.AllowedPrincipal = {
    import AllowedPrincipal.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.AllowedPrincipal
      .builder()
      .optionallyWith(principalType.map(value => value.unwrap))(_.principalType)
      .optionallyWith(principal.map(value => value: java.lang.String))(
        _.principal
      )
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.AllowedPrincipal.ReadOnly =
    zio.aws.ec2.model.AllowedPrincipal.wrap(buildAwsValue())
}
object AllowedPrincipal {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.AllowedPrincipal
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.AllowedPrincipal =
      zio.aws.ec2.model.AllowedPrincipal(
        principalType.map(value => value),
        principal.map(value => value)
      )
    def principalType: Option[zio.aws.ec2.model.PrincipalType]
    def principal: Option[String]
    def getPrincipalType: ZIO[Any, AwsError, zio.aws.ec2.model.PrincipalType] =
      AwsError.unwrapOptionField("principalType", principalType)
    def getPrincipal: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("principal", principal)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.AllowedPrincipal
  ) extends zio.aws.ec2.model.AllowedPrincipal.ReadOnly {
    override val principalType: Option[zio.aws.ec2.model.PrincipalType] = scala
      .Option(impl.principalType())
      .map(value => zio.aws.ec2.model.PrincipalType.wrap(value))
    override val principal: Option[String] =
      scala.Option(impl.principal()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.AllowedPrincipal
  ): zio.aws.ec2.model.AllowedPrincipal.ReadOnly = new Wrapper(impl)
}
